@@ -1,18 +1,23 @@
 package HTML::Template::Compiled::Token;
-# $Id: Token.pm,v 1.5 2006/10/02 17:39:59 tinita Exp $
+# $Id: Token.pm,v 1.8 2006/10/20 19:46:59 tinita Exp $
 use strict;
 use warnings;
 use Carp qw(croak carp);
+use base qw(Exporter);
+our @EXPORT_OK = qw(&NO_TAG &OPENING_TAG &CLOSING_TAG);
+our %EXPORT_TAGS = (
+    tagtypes => [qw(&NO_TAG &OPENING_TAG &CLOSING_TAG)],
+);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use constant ATTR_TEXT       => 0;
 use constant ATTR_LINE       => 1;
-use constant ATTR_OPEN       => 2;
+use constant ATTR_OPEN_CLOSE => 2;
 use constant ATTR_NAME       => 3;
 use constant ATTR_ATTRIBUTES => 4;
-use constant ATTR_CLOSE      => 5;
-use constant ATTR_FILE      => 6;
+use constant ATTR_FILE       => 5;
+use constant ATTR_LEVEL      => 6;
 
 use constant NO_TAG        => 0;
 use constant OPENING_TAG   => 1;
@@ -37,14 +42,14 @@ sub get_name       { $_[0]->[ATTR_NAME] }
 sub set_name       { $_[0]->[ATTR_NAME] = $_[1] }
 sub get_line       { $_[0]->[ATTR_LINE] }
 sub set_line       { $_[0]->[ATTR_LINE] = $_[1] }
-sub get_open       { $_[0]->[ATTR_OPEN] }
-sub set_open       { $_[0]->[ATTR_OPEN] = $_[1] }
-sub get_close      { $_[0]->[ATTR_CLOSE] }
-sub set_close      { $_[0]->[ATTR_CLOSE] = $_[1] }
+sub get_open_close { $_[0]->[ATTR_OPEN_CLOSE] }
+sub set_open_close { $_[0]->[ATTR_OPEN_CLOSE] = $_[1] }
 sub get_attributes { $_[0]->[ATTR_ATTRIBUTES] }
 sub set_attributes { $_[0]->[ATTR_ATTRIBUTES] = $_[1] }
-sub get_file { $_[0]->[ATTR_FILE] }
-sub set_file { $_[0]->[ATTR_FILE] = $_[1] }
+sub get_file       { $_[0]->[ATTR_FILE] }
+sub set_file       { $_[0]->[ATTR_FILE]       = $_[1] }
+sub get_level      { $_[0]->[ATTR_FILE] }
+sub set_level      { $_[0]->[ATTR_FILE]       = $_[1] }
 
 package HTML::Template::Compiled::Token::Text;
 use Carp qw(croak carp);
